SQLAlchemy 0.5 Documentation - module sqlalchemy.databases.sybase

# SQLAlchemy 0.5 Documentation

Multiple Pages | One Page
Version: 0.5.0beta2 Last Updated: 07/14/08 16:12:25

### module sqlalchemy.databases.sybase

Sybase database backend.

Known issues / TODO:

> - Uses the mx.ODBC driver from egenix (version 2.1.0)

> - The current version of sqlalchemy.databases.sybase only supports mx.ODBC.Windows (other platforms such as mx.ODBC.unixODBC still need some development)

> - Support for pyodbc has been built in but is not yet complete (needs further development)

> - Results of running tests/alltests.py:

>     Ran 934 tests in 287.032s FAILED (failures=3, errors=1)

> - Tested on 'Adaptive Server Anywhere 9' (version 9.0.1.1751)

### class SybaseBigInteger(SybaseInteger)

def get_col_spec(self)
back to section top

### class SybaseBinary(Binary)

def get_col_spec(self)
back to section top

### class SybaseBoolean(Boolean)

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SybaseChar(CHAR)

def get_col_spec(self)
back to section top

### class SybaseDateTime_mxodbc(DateTime)

def __init__(self, *a, **kw)

Construct a new `SybaseDateTime_mxodbc`.

def get_col_spec(self)
back to section top

### class SybaseDateTime_pyodbc(DateTime)

def __init__(self, *a, **kw)

Construct a new `SybaseDateTime_pyodbc`.

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SybaseDate_mxodbc(Date)

def __init__(self, *a, **kw)

Construct a new `SybaseDate_mxodbc`.

def get_col_spec(self)
back to section top

### class SybaseDate_pyodbc(Date)

def __init__(self, *a, **kw)

Construct a new `SybaseDate_pyodbc`.

def get_col_spec(self)
back to section top

### class SybaseFloat(FLOAT,SybaseNumeric)

def __init__(self, precision=10, asdecimal=False, length=2, **kwargs)

Construct a new `SybaseFloat`.

def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SybaseInteger(Integer)

def get_col_spec(self)
back to section top

### class SybaseMoney(TypeEngine)

def get_col_spec(self)
back to section top

### class SybaseSmallInteger(SybaseInteger)

def get_col_spec(self)
back to section top

### class SybaseSmallMoney(SybaseMoney)

def get_col_spec(self)
back to section top

### class SybaseString(String)

def get_col_spec(self)
back to section top

### class SybaseText(Text)

def get_col_spec(self)
back to section top

### class SybaseTimeStamp(TIMESTAMP)

def get_col_spec(self)
back to section top

### class SybaseTime_mxodbc(Time)

def __init__(self, *a, **kw)

Construct a new `SybaseTime_mxodbc`.

def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SybaseTime_pyodbc(Time)

def __init__(self, *a, **kw)

Construct a new `SybaseTime_pyodbc`.

def bind_processor(self, dialect)
def get_col_spec(self)
def result_processor(self, dialect)
back to section top

### class SybaseTinyInteger(SybaseInteger)

def get_col_spec(self)
back to section top

### class SybaseUniqueIdentifier(TypeEngine)

def get_col_spec(self)
back to section top